@@ -25,7 +25,6 @@ JSON parsing inspired by https://stackoverflow.com/a/58442063
 import select
 import sys
 import os
-import fcntl
 import re
 import logging
 import argparse
@@ -52,7 +51,6 @@ from nav.config import open_configfile
 from nav.buildconf import VERSION as _NAV_VERSION
 
 from django.urls import reverse
-from django.db.models import Q
 
 
 _logger = logging.getLogger("navargus")
@@ -122,9 +120,7 @@ def read_eventengine_stream():
         os.getpid(),
         version,
     )
-    fd = sys.stdin.fileno()
-    flag = fcntl.fcntl(fd, fcntl.F_GETFL)
-    fcntl.fcntl(fd, fcntl.F_SETFL, flag | os.O_NONBLOCK)
+    os.set_blocking(sys.stdin.fileno(), False)
 
     try:
         for alert in emit_json_objects_from(sys.stdin):
@@ -157,6 +153,16 @@ def emit_json_objects_from(stream, buf_size=1024, decoder=JSONDecoder()):
             _logger.debug("reading data from %r", stream)
             block = stream.read(buf_size)
             if not block:
+                if not last_block_size:
+                    # select() will keep claiming that the input handle has data
+                    # available when the input pipe is actually gone. If we read two
+                    # empty blocks in a row, we take it as a sign that our input is
+                    # gone, and we should exit.
+                    _logger.info(
+                        "read multiple empty blocks in a row, maybe input went away. "
+                        "aborting..."
+                    )
+                    return
                 last_block_size = 0
                 continue
             last_block_size = len(block)
